@@ -68,7 +68,7 @@ extern struct kmem_cache *xfs_trans_cache;
 
 /* fake up iomap, (not) used in xfs_bmap.[ch] */
 #define IOMAP_F_SHARED				0x04
-#define xfs_bmbt_to_iomap(a, b, c, d, e)	((void) 0)
+#define xfs_bmbt_to_iomap(a, b, c, d, e, f)	((void) 0)
 
 /* CRC stuff, buffer API dependent on it */
 #define crc32c(c,p,l)	crc32c_le((c),(unsigned char const *)(p),(l))
